# woRkflow

How we do collaborative reproducible data analysis and reporting. Mostly (but not only) using R. Inspired by [@AlexaLFH](https://twitter.com/AlexaLFH/status/1261633918782013440).

This repo does three things:

 * it is a collection of R [how-to resources](howTo/) including some notes on:
   * how to [use git branches](howTo/gitBranches.md) 
   * how to use [drake](howTo/drake.md) to massively speed up and [manage your workflow](https://milesmcbain.xyz/the-drake-post/) (NB: drake has been superseded by [targets](https://books.ropensci.org/targets/) - update on the notes soon)
   * how to access the University [Iridis HPC](howTo/iridis.md)
   * how to use R/RStudio on the University [SVE (remote desktop) service](howTo/sve.md)
   * where to [keep your data](howTo/keepingData.md)
   * how to use [renv](howTo/renv.md) to manage your R environment - including packages
   * how to access Amazon Web Services S3 buckets directly from R using [aws.s3](howTo/aws-s3.md)
 * it is a [template](repoAsATemplate.md) repo that illustrates how we work and which you can copy;
 * it is an R package. This means:
     * package functions are kept in /R
     * help files auto-created by roxygen are in /man
     * if you clone it you can build it using 'install and restart' from the RStudio Build menu and use the functions viz: `woRkflow::functionName()` (not that it has many)
 
Using drake:
 
 * make_XX.R contains a call to drake::r_make(source = "_drake_XX.R")
 * _drake_XX.R contains the drake plan and the functions & package loading. This is not quite what the [drake book](https://books.ropensci.org/drake/projects.html#usage) recommends but it works for us
 * Rmd scripts called by the drake plan to report results are kept in /Rmd
 * outputs are kept in /docs (reports, plots etc)
 * if you can, **run Rscript ./make_cleanFeeders.R in a terminal not at the RStudio console** <- this stops RStudio from locking up

We'd love your [contributions](CONTRIBUTING.md) - feel free to:

 * [fork & go](https://happygitwithr.com/fork-and-clone.html)
 * make a [new branch](https://git.soton.ac.uk/SERG/workflow/-/blob/master/howTo/gitBranches.md) in your fork
 * make some improvements
 * send us a pull request (just code, no data please, keep your data [elsewhere](https://git.soton.ac.uk/SERG/workflow/-/blob/master/howTo/keepingData.md)!)

As a number of people have pointed out [fork & go](https://happygitwithr.com/fork-and-clone.html) only works if you have an account on git.soton.ac.uk. If you don't, you can import the repo to (for example) your [github.com](https://github.com/new/import) account and go from there. And presumably on gitlab.com too...
