# Requires aws.s3 package install if required
# install.packages("aws.s3")

# Set environment variables to use AWS access keys
source("./howTo/r-with-aws/access_keys/aws_access.R") # Replace with your credentials e.g. next line
# source("./howTo/r-with-aws/access_keys/example_credentials_script.R")

# Get list of buckets
aws.s3::bucketlist()

# set bucket name (less typing) - this is the name of your s3 bucket
my_bucket <- "twr-test-bucket-r"

# write a file to temp dir - using a built in data frame
write.csv(iris, file.path(tempdir(), "iris.csv"))

# save an object (file from the temp dir) to the bucket
aws.s3::put_object(
  file = file.path(tempdir(), "iris.csv"), 
  object = "iris.csv", 
  bucket = my_bucket
)

# list objects in the bucket
aws.s3::get_bucket(
  bucket = my_bucket
)

# provide a nice table of objects in the bucket
data.table::rbindlist(aws.s3::get_bucket(bucket = my_bucket))

# read an object from s3 bucket, three ways ...

# 1. bucket and object specified separately
aws.s3::s3read_using(
  FUN = read.csv, bucket = my_bucket, object = "iris.csv"
  )

# 2. use the s3 URI
aws.s3::s3read_using(
  FUN = read.csv, object = "s3://twr-test-bucket-r/iris.csv"
  )

# 3. use data.table's fread() function for fast CSV reading
aws.s3::s3read_using(
  FUN = data.table::fread, object = "s3://twr-test-bucket-r/iris.csv"
  )

